# encoding: UTF-8
module SplitHelper
  # Generuje celostránkovou tabulku splitů a jejich transferů.
  # Použití v kódu je následující:
  # @example
  #  <% transfer_table [@columns1,@columns2], :starting_balance => {'CZK'=>12,'EUR'=>45} do |tt| %>
  #    <%= tt.header %>
  #    <%= tt.body(@transfers) %>
  #  <% end %>
  # Popis parametrů +transfer_table+ je u metody 
  # 
  # @author Jakub Těšínský
  class SplitTable < BlockHelpers::Base
    # @param [Columns, Array] columns for the table, pokud obsahuje pole polí, pak každý item bude mít více řádků
    # @param [Hash] options the options for the table
    # @option options [Hash] :starting_balance
    #   udává jaká je počáteční balance která se potom s jednotlivými řádky přepočítává
    def initialize(columns, options={})
      @table_columns = prepare_columns(columns)
      @table_balance = options[:starting_balance]
      @balance ||= Hash.new()
    end
    # Připraví sloupce - aby bylo možno rozeznat různé formáty.
    # @private
    # @param columns (see #initialize)
    def prepare_columns(columns) 
      if columns == []
        [[]]
      elsif columns[0].class == Array
        columns
      else
        [columns]
      end
    end
    def display(body)
      if params[:format] == 'xml'
        %(
          <SeznamPokDokl>
            #{body}
          </SeznamPokDokl>
        )
      else
        %(
<div id="transfers">
<table cols="#{ @table_columns[0].length }">
  #{body}
</table>
</div>
        )
      end.html_safe
    end
    # záhlaví tabulky
    def header(starting_balance=Hash.new())
      if !@table_balance.nil? and !@table_balance.zero?
        @starting_balance_column = @table_columns[0].length - 1
        @table_columns[0].each_index { |index|
          if @table_columns[0][index].id == 'balance_rich'
            @starting_balance_column = index
          end
        }
        render :partial => 'transfers/table_header',
          :locals =>{:columns => @table_columns, :starting_balance => @table_balance, :starting_balance_column => @starting_balance_column}
      else
        render :partial => 'transfers/table_header', :locals =>{:columns => @table_columns}
      end
    end
    # tělo tabulky
    # @param [[Split, ...]] splits pole splitů, které se mají zobrazit
    # @option options [Hash] :add_reconciled_class přidává css class v případě že je Split reconcilovaný
    # @option options [Hash] :add_highlighted_class přidává css class v případě že je Split selectovaný
    def body(splits, options={})
      options.reverse_merge! :add_reconciled_class=>false
      options.reverse_merge! :add_highlighted_class=>true
      render :partial => 'splits/table_row', :collection => splits,
               :locals =>{:columns => @table_columns, :options=>options}
    end
  end

end